OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fil d’activités personnelles de %s",
    "Your feed URL is invalid" : "Votre URL de fil d’activité n’est pas valide",
    "Activity feed for %1$s" : "Flux d’activités pour %1$s",
    "Activity feed" : "Fil d’activité",
    "Your settings have been updated." : "Vos paramètres ont été mis à jour.",
    "Settings have been updated." : "Les paramètres ont été mis à jour.",
    "remote user" : "utilisateur distant",
    "Recent activity" : "Activités récentes",
    "No activities" : "Aucune activité",
    "More activities" : "Plus d’activités",
    "Daily activity summary for %s" : "Résumé de l’activité du jour pour %s",
    "_and %n more…_::_and %n more…_" : ["et %n de plus…","et %n en plus…","et %n de plus…"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Vous pouvez désactiver les e-mails quotidiens récapitulatifs dans les <a href=\"%s\">paramètres.</a>",
    "You can disable daily digest emails in the settings: %s" : "Vous pouvez désactiver les e-mails quotidiens récapitulatifs dans les paramètres: %s",
    "All activities" : "Toutes les activités",
    "By others" : "Des autres",
    "By you" : "De vous",
    "Activity at %s" : "Activité sur %s",
    "Hello %s" : "Bonjour %s,",
    "Hello %s," : "Bonjour %s,",
    "There was some activity at %s" : "Il y a eu de l’activité sur %s",
    "_and %n more _::_and %n more _" : ["et %n autre","et %n autres","et %n autres"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Vous pouvez changer la fréquence de ces e-mails ou les désactiver dans les <a href=\"%s\">paramètres</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Vous pouvez changer la fréquence de ces e-mails ou les désactiver dans les paramètres : %s",
    "Mail" : "E-mail",
    "Push" : "Push",
    "Activity" : "Activité",
    "Notifications" : "Notifications",
    "This application enables people to view a log of activities about them, their files or other data." : "Cette application permet aux personnes de visualiser les logs des activités les concernant, leurs fichiers ou d’autres données.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Cette application permet aux utilisateurs de visualiser les actions relatives à leurs fichiers et données dans Nextcloud.\n\t\tChaque personne peut configurer ses options d’activité individuelle dans les paramètres personnels,\n\t\tpour choisir quelles activités devraient être poussées vers les téléphones mobiles, envoyées par e-mail,\n\t\tou si un résumé quotidien est envoyé chaque matin.\n\t\tPlus d’informations sont accessibles dans la documentation d’Activité.",
    "Send email" : "Envoyer un e-mail",
    "Send push notification" : "Envoyer des notifications push",
    "Activity notification configuration" : "Configuration des notifications d’activité",
    "Today" : "Aujourd’hui",
    "Yesterday" : "Hier",
    "You need to set up your email address before you can receive notification emails." : "Vous devez spécifier votre adresse e-mail pour pouvoir recevoir des notifications par e-mail.",
    "Send activity emails" : "Envoyer des e-mails d’activité",
    "As soon as possible" : "Dès que possible",
    "Hourly" : "Toutes les heures",
    "Daily" : "Quotidiennement",
    "Weekly" : "Chaque semaine",
    "You commented" : "Vous avez commenté",
    "Message deleted by author" : "Message supprimé par l’auteur",
    "Open {filename}" : "Ouvrir {filename}",
    "in {path}" : "dans {path}",
    "Home" : "Accueil",
    "Could not load activities" : "Impossible de charger les activités",
    "Loading activities" : "Chargement des activités",
    "This stream will show events like additions, changes & shares" : "Ce flux liste les événements tels que les ajouts, les modifications et les partages",
    "No activity yet" : "Pas encore d’activité",
    "Loading more activities" : "Chargement de plus d’activités",
    "No more activities." : "Plus aucune autre activité",
    "Could not enable RSS link" : "Impossible d’activer le lien RSS",
    "RSS link copied to clipboard" : "Lien RSS copié dans le presse-papier",
    "Could not copy the RSS link, please copy manually:" : "Impossible de copier le lien RSS, merci de le copier manuellement :",
    "Activity settings" : "Paramètres de Activité",
    "Enable RSS feed" : "Activer les flux RSS",
    "RSS feed" : "Flux RSS",
    "Copy RSS feed link" : "Copier le lien du flux RSS",
    "Personal notification settings" : "Paramètres des notifications personnelles",
    "Unable to load the activity list" : "Impossible de charger la liste des activités",
    "Choose for which activities you want to get an email or push notification." : "Sélectionnez les activités pour lesquelles vous souhaitez recevoir une notification par e-mail ou une notification push.",
    "Choose for which activities you want to get a push notification." : "Sélectionnez les activités pour lesquelles vous souhaitez recevoir une notification push.",
    "Notification" : "Notification",
    "Enable notification emails" : "Activer les notifications par e-mail",
    "Daily activity summary" : "Résumé journalier des activités",
    "Send daily activity summary in the morning" : "Recevoir un résumé des activités chaque matin",
    "Default settings" : "Paramètres par défaut",
    "Configure the default notification settings for new accounts." : "Configurer les paramètres de notification par défaut pour les nouveaux comptes.",
    "Unable to save the settings" : "Échec de l’enregistrement des paramètres",
    "No more events to load" : "Plus aucun événement à charger"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
